/*
 * Copyright 2013 Red Hat Inc. and/or its affiliates and other contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.switchyard.common.property;

import java.util.Map;

/**
 * Resolves properties from a Map.
 *
 * @author David Ward &lt;<a href="mailto:dward@jboss.org">dward@jboss.org</a>&gt; &copy; 2012 Red Hat Inc.
 */
public class MapPropertyResolver implements PropertyResolver {

    private final Map<String, Object> _map;

    /**
     * Construction with the specified Map.
     * @param map the specified Map
     */
    public MapPropertyResolver(Map<String, Object> map) {
        _map = map;
    }

    /**
     * Gets the Map.
     * @return the Map
     */
    public Map<String, Object> getMap() {
        return _map;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public final Object resolveProperty(String key) {
        return key != null ? _map.get(key) : null;
    }

}
